<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class Coz07020 extends \Zeedhi\Framework\Controller\Report {
    
    protected $novoCodigo;
    protected $entityManager;
    protected $birtStrategy;
    protected $environment;
    protected $crudService;
    protected $connection;
    protected $nrlistaserv;
    protected $nrlistaprod;
    protected $dataSourceManager;
    protected $dataSourceName;
    
    const TABLE_LISTA = "LISTA";
    
    public function __construct($reportService, $novoCodigo, $entityManager, $environment, $birtStrategy, $crudService,  $connection,$dataSourceManager) {
        $this->reportService      = $reportService;
        $this->novoCodigo         = $novoCodigo;
        $this->environment        = $environment;
        $this->entityManager      = $entityManager;
        $this->birtStrategy       = $birtStrategy;
        $this->crudService   = $crudService;
        $this->connection         = $connection;
        $this->dataSourceManager = $dataSourceManager;
    }
    
    protected $reportMapping = array (
      'mcoz07020' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'P_CDCENTRAL'    => 'P_CDCENTRAL',
                'P_NRORG'        => 'P_NRORG',
                'P_NRPLANPROD'   => 'P_NRPLANPROD',
                'P_NRETIQUETACOZ'=> 'P_NRETIQUETACOZ',
                'P_LISTAFILSERV' => 'P_LISTAFILSERV',
                'P_DTPRODINI'    => 'P_DTPRODINI',
                'P_DTPRODFIN'    => 'P_DTPRODFIN',
                'P_LISTAPROD'    => 'P_LISTAPROD',
                'P_NRCARDACLIPLANPROD'    => 'P_NRCARDACLIPLANPROD',
            ),
        )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $cdfiliserv = $row["LISTASERVFILI"];
        $cdprod = $row["LISTAPROD"];
        $this->nrlistaserv = $this->insertLista($cdfiliserv);
        $this->nrlistaprod = $this->insertLista($cdprod);
        
        //ROW PRO BIRT 
        $row["P_LISTAFILSERV"] = $this->nrlistaserv;
        $row["P_LISTAPROD"] = $this->nrlistaprod;
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
    }
    
    private function insertLista($cdlistaArray) {
        $this->dataSourceName = strtolower(self::TABLE_LISTA);
        $nrlista = $this->novoCodigo->getCodeByTableName(self::TABLE_LISTA, $this->environment->getNrOrg());;
        $rows = array();
        foreach ($cdlistaArray as $cdlista) {
            $row = array(
                "NRLISTA"  => $nrlista,
                "CDLISTA"  => $cdlista,
                "__is_new" => true,
                "NRORG"    => $this->environment->getNrorgTrab()
            );
            array_push($rows, $row);
        }
        $dataSet = new DataSet($this->dataSourceName, $rows);
        $request = new DTO\Request\DataSet($dataSet, "", "", "");
        $rowsToSave = $this->crudService->getRowsToSave($request, $this->dataSourceName);
        $this->crudService->save($this->dataSourceName, $rowsToSave);
        return $nrlista;
    }
    
    private function deleteLista($nrlista) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        
        $conditions = array(
            array(
                "columnName" => "NRLISTA",
                "operator"   => '=',
                "value"      => $nrlista
            )
        );
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);
        $this->dataSourceManager->delete($dataSet);
    }
    
    public function afterProcessReport(DTO\Request\Row $request, DTO\Response $response, $report) {
        // $this->deleteLista($this->nrlistaprod);
        // $this->deleteLista($this->nrlistaserv);
    }
}